@@ -6,13 +6,13 @@ function(cop=NULL, para=NULL, secondary=FALSE,
          xlab="U=V, NONEXCEEDANCE PROBABILITY",
          ylab="H, NONEXCEEDANCE PROBABILITY")
   }
-  T <- seq(0+delt,1-delt,delt)
-  C <- sapply(T, function(x) {
+  TT <- seq(0+delt, 1-delt, delt)
+  C <- sapply(TT, function(x) {
           	        y <- x
           	        if(secondary) y <- 1 - y
           	        return( cop(x,y, para=para, ...)) } )
-  if(lines & ! is.null(dev.list())) lines(T,C, ...)
+  if(lines & ! is.null(dev.list())) lines(TT, C, ...)
   txt <- "primary"
   if(secondary) txt <- "secondary"
-  return(list(t=T, diagcop=C, diagtype=txt))
+  return(list(t=TT, diagcop=C, diagtype=txt))
 }
